
// ******************** 
// NMEA Library Example for Clicker2 & Survivor
// ************************
// Setup:
// - GPS module should be connected to RG1 pin (UART2 RX)
// - Change the baud rate defined in preprocessor to match that of your GPS module
// - NMEA 18F library must be checked
//*********************************************************************************
#define Directory "C:\_MikroC\_MesProjets_MikroC\_18F87J50_GPS"
#define Projet "NMEA_Library_test.mcppi"
#define Source "

#define BAUD_RATE 19200   // was 9600

/* Begin LCD 2x16 mode connections
sbit LCD_RS at LATB4_bit;
sbit LCD_EN at LATB5_bit;
sbit LCD_D4 at LATB0_bit;
sbit LCD_D5 at LATB1_bit;
sbit LCD_D6 at LATB2_bit;
sbit LCD_D7 at LATB3_bit;

sbit LCD_RS_Direction at TRISB4_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D4_Direction at TRISB0_bit;
sbit LCD_D5_Direction at TRISB1_bit;
sbit LCD_D6_Direction at TRISB2_bit;
sbit LCD_D7_Direction at TRISB3_bit;
// End LCD connections
*/

//  Specific Clicker2 18F

// specific to Clicker2 PIC18F87J50
sbit LD1 at LATD4_bit;
sbit LD2 at LATE4_bit;
sbit LD1_Direction at TRISD4_bit;
sbit LD2_Direction at TRISE4_bit;

sbit RE6_FAULT at RE6_bit;
sbit RE5_SENSEL at LATE5_bit;   // cde FET M1
sbit RJ5_Stat at RJ5_bit;
sbit RF6_VSENSE at RF6_bit;    // mesure


sbit Led_Rouge at LATD4_bit;
sbit Led_Rouge_Directiont at TRISD4_bit;

sbit BP1 at RD7_bit;
sbit BP2 at RH3_bit;
sbit BP1_Direction at TRISD7_bit;
sbit BP2_Direction at TRISH3_bit;



sbit NMEA_IntFlag at RC2IF_bit;  // NMEA Library RX Interrupt flag

char buffer[128];                // Primary buffer
char nmea[128];                  // NMEA sentence
char rcvd = 0;                   // NMEA sentence received flag


void CRLF1();



void CRLF1()
{
UART1_Write(13);
UART1_Write(10);
}





void interrupt() {
   NMEA_IntHandler();
}

// Callback function called on reception of NMEA sentence
void NMEA_DataReceived() {
   rcvd = 1;
}

void DisplayData(char * caption, char * txt) {
   UART1_Write_Text(caption);
   UART1_Write(9);
   UART1_Write_Text(txt);
   CRLF1();
 /*
   Lcd_Cmd(_LCD_CLEAR);
   Lcd_Out(1, 1, caption);
   Lcd_Out(2, 1, txt);
 */
   Delay_ms(1000);
}



 void Hardware_Init(void)
 {

  ANCON0=0xFD ; // AN1= analog
  ANCON1=0xFF; // No analog on AN15--AN10
  TRISA=0xFF;
  TRISA2_bit=0; // output for UART asm TX output
  TRISB=0xFF;
  TRISD=0xFF;
  TRISC=0xFF;
  TRISG=0xFF;

  TRISD6_bit=0;

  BP1_Direction = 1;         // Set direction for buttons
  BP2_Direction = 1;
  LD1_Direction = 0;        // Set direction for LEDs
  LD2_Direction = 0;
  LD1 = 0;                  // turn off LEDs
  LD2 = 0;
  //PPS_Direction=1;
  }

void main() {
   char gps_data[20];
   char tmp[2];

  // ANSELB = 0;
  // ANSELC = 0;
   Hardware_Init() ;

  // Lcd_Init();
  // Lcd_Cmd(_LCD_CLEAR);
  // Lcd_Cmd(_LCD_CURSOR_OFF);

   UART1_Init(19200);
   UART2_Init(BAUD_RATE);

   NMEA_Init(&UART2_Read, buffer, sizeof(buffer));

   RC2IE_bit = 1;   // UART2 Interrupt Enable
   PEIE_bit  = 1;   // Peripheral Interrupt Enable
   GIE_bit   = 1;   // Global Interrupt Enable
   UART1_Write_Text("Test NMEA 18F library with SURVIVOR PIC18F87J50\r\n");
    UART1_Write_Text("GPS NEO-6M sur RG1 & RG2 UART2 at 19200 bds\r\n");
      UART1_Write_Text("Display via UART1 RC7 RC6 on TeraTerm terminal 19200 bds\r\n");
   CRLF1();
   while(1) {
      if (rcvd) {
         strcpy(nmea, buffer);   // double buffering

         // If checksum is correct and sentence is GGA
         if (NMEA_IsValid(nmea) && strstr(nmea, "$GPGGA")) {
            // Display UTC time
            NMEA_Split(gps_data, nmea, ',', 1);
            DisplayData("UTC Time:", gps_data);

            // Display latitude
            NMEA_Split(gps_data, nmea, ',', 2);
            NMEA_Split(tmp, nmea, ',', 3);
            strcat(gps_data, tmp);
            DisplayData("Latitude:", gps_data);

            // Display longitude
            NMEA_Split(gps_data, nmea, ',', 4);
            NMEA_Split(tmp, nmea, ',', 5);
            strcat(gps_data, tmp);
            DisplayData("Longitude:", gps_data);

            // Display fix quality
            NMEA_Split(gps_data, nmea, ',', 6);
            DisplayData("Fix quality:", gps_data);

            // Display number of satellites
            NMEA_Split(gps_data, nmea, ',', 7);
            DisplayData("Num of sats:", gps_data);
            
            CRLF1();
         }
         rcvd = 0;
      }
   }
}
/*

 Test NMEA library with clicker2 PIC18F87J50
GPS NEO-6M sur RG1 & RG2 UART2 at 19200 bds
Display via UART1 RC7 RC6 on TeraTerm terminal 19200 bds

UTC Time:	153215.00
Latitude:	4550.72617N
Longitude:	00502.32601E
Fix quality:	2
Num of sats:	09

UTC Time:	153223.00
Latitude:	4550.72575N
Longitude:	00502.32577E
Fix quality:	2
Num of sats:	09

UTC Time:	153231.00
Latitude:	4550.72538N
Longitude:	00502.32577E
Fix quality:	2
Num of sats:	09


0 1 mikroCPIC1618.exe -MSF -DBG -pP18F87J50 -RA -GC -C -O11111114 -fo48 -N"C:\_MikroC\mikroC PRO for PIC\Packages\NMEA Library\Examples\NMEA LCD\NMEA_LCD.mcppi" -SP"C:\_MikroC\mikroC PRO for PIC\Defs\" -SP"C:\_MikroC\mikroC PRO for PIC\uses\P18\" -SP"C:\_MikroC\mikroC PRO for PIC\Packages\NMEA Library\Examples\NMEA LCD\" -SP"C:\Users\Public\Documents\Mikroelektronika\mikroC PRO for PIC\defs\" -SP"C:\Users\Public\Documents\Mikroelektronika\mikroC PRO for PIC\uses\P18\" -SP"C:\Users\Administrator\Desktop\NMEA Library\Examples\mikroC\" -SP"C:\Users\Public\Documents\Mikroelektronika\mikroC PRO for PIC\Packages\NMEA Library\Uses\" -SP"C:\_MikroC\mikroC PRO for PIC\Packages\NMEA Library\Uses\" "NMEA_UART2_Display_UART1.c" "__Lib_Math.mcl" "__Lib_MathDouble.mcl" "__Lib_System.mcl" "__Lib_Delays.mcl" "__Lib_CString.mcl" "__Lib_UART_c67g12.mcl" "__Lib_LcdConsts.mcl" "__Lib_Lcd.mcl" "__Lib_NMEA_P18.mcl"
0 1501 Specified search path does not exist: 'C:\Users\Public\Documents\Mikroelektronika\mikroC PRO for PIC\defs'
0 1501 Specified search path does not exist: 'C:\Users\Public\Documents\Mikroelektronika\mikroC PRO for PIC\uses\P18'
0 1501 Specified search path does not exist: 'C:\Users\Administrator\Desktop\NMEA Library\Examples\mikroC'
0 1501 Specified search path does not exist: 'C:\Users\Public\Documents\Mikroelektronika\mikroC PRO for PIC\Packages\NMEA Library\Uses'
0 1139 Available RAM: 3883 [bytes], Available ROM: 131064 [bytes]
0 122 Compilation Started P18F87J50.c
3055 123 Compiled Successfully P18F87J50.c
0 122 Compilation Started __Lib_Delays.c
172 123 Compiled Successfully __Lib_Delays.c
0 122 Compilation Started NMEA_UART2_Display_UART1.c
134 1509 Generated baud rate is 38462 bps (error = 0.16 percent) NMEA_UART2_Display_UART1.c
181 123 Compiled Successfully NMEA_UART2_Display_UART1.c
0 127 All files Compiled in 47 ms
0 1144 Used RAM (bytes): 541 (14%)  Free RAM (bytes): 3342 (86%) Used RAM (bytes): 541 (14%)  Free RAM (bytes): 3342 (86%)
0 1144 Used ROM (bytes): 2619 (2%)  Free ROM (bytes): 128445 (98%) Used ROM (bytes): 2619 (2%)  Free ROM (bytes): 128445 (98%)
0 125 Project Linked Successfully NMEA_LCD.mcppi
0 1004 COFF file successfully generated COFF file successfully generated
0 128 Linked in 1109 ms
0 129 Project 'NMEA_LCD.mcppi' completed: 1297 ms
0 103 Finished successfully: 28 aot 2016, 16:59:44 NMEA_LCD.mcppi

*/